FREAcquireBitmapData2

Function FREAcquireBitmapData2 

pub unsafe extern "C" fn FREAcquireBitmapData2(
    object: *mut c_void,
    descriptorToSet: *mut FREBitmapData2,
) -> FREResult
Referenced data is valid only for duration of the call to a registered function.

Use of this API requires that the extension and application must be packaged for the 3.1 namespace or later.

@return FREResult::FRE_OK FREResult::FRE_TYPE_MISMATCH FREResult::FRE_INVALID_OBJECT FREResult::FRE_INVALID_ARGUMENT FREResult::FRE_WRONG_THREAD FREResult::FRE_ILLEGAL_STATE