FREContextInitializer

Type Alias FREContextInitializer 

pub type FREContextInitializer = unsafe extern "C" fn(*mut c_void, *const u8, *mut c_void, *mut u32, *mut *const FRENamedFunction);
Defines the signature for the initializer that is called each time a new AS ExtensionContext object is created.

@param extData The extension client data provided to the FREInitializer function as extDataToSet.

@param ctxType Pointer to the contextType string (UTF8) as provided to the AS createExtensionContext call.

@param ctx The FREContext being initialized.

@param numFunctionsToSet The number of elements in the functionsToSet array.

@param functionsToSet A pointer to an array of FRENamedFunction elements.