FREFunction

Type Alias FREFunction 

pub type FREFunction = unsafe extern "C" fn(*mut c_void, *mut c_void, u32, *const *mut c_void) -> *mut c_void;
Defines the signature for native calls that can be invoked via an instance of the AS ExtensionContext class.

@return The return value corresponds to the return value from the AS ExtensionContext class call() method. It defaults to FREResult::FRE_INVALID_OBJECT, which is reported as null in AS.