pub unsafe extern "C" fn FREAcquireBitmapData2(
object: *mut c_void,
descriptorToSet: *mut FREBitmapData2,
) -> FREResultExpand description
Referenced data is valid only for duration of the call to a registered function.
Use of this API requires that the extension and application must be packaged for the 3.1 namespace or later.