FREGetFREContextFromExtensionContext

Function FREGetFREContextFromExtensionContext 

pub unsafe extern "C" fn FREGetFREContextFromExtensionContext(
    objExtensionContext: *mut c_void,
    pContext: *mut *mut c_void,
) -> FREResult
Get the FREContext object associated with any ExtensionContext object. Note that the FREContext object may become invalid based on what happens with the other ExtensionContext, so this value should not be cached between function calls.

Parameters

  • objExtensionContext: The ExtensionContext (AS3 object) for which the FREContext handle is required.
  • pContext: The FREContext (C handle) associated with the given ExtensionContext.

Returns