FREGetObjectAsUTF8

Function FREGetObjectAsUTF8 

pub unsafe extern "C" fn FREGetObjectAsUTF8(
    object: *mut c_void,
    length: *mut u32,
    value: *mut *const u8,
) -> FREResult
Retrieves a string representation of the object referred to by the given object. The referenced string is immutable and valid only for duration of the call to a registered function. If the caller wishes to keep the string, they must keep a copy of it.

Parameters

  • object: The string to be retrieved.
  • length: The size, in bytes, of the string. Includes the NUL terminator.

๐Ÿ˜ก๐Ÿ‘†

IT DOES NOT INCLUDE THE NUL TERMINATOR IN PRACTICE (AIR-SDK-51.1.3.1).

  • value: A pointer to a possibly temporary copy of the string.

Returns