FREGetRenderMode

Function FREGetRenderMode 

pub unsafe extern "C" fn FREGetRenderMode(
    ctx: *mut c_void,
    stage: *mut c_void,
    pRenderMode: *mut FRERenderMode,
) -> FREResult
Returns the current render mode and mechanism for AIR

Parameters

  • stage: The AS3 Stage object for which to return the render mode. If this parameter is passed as null, the function will use the main/initial stage.
  • pRenderMode: A pointer to a byte that will be populated with one of the render modes from the FRERenderMode enumeration.

Returns