FREStr

Type Alias FREStr 

pub type FREStr = *const u8;
Borrowed pointer to UTF-8 string.

This is a pointer to the beginning of the string buffer only. Length and termination are determined by the API contract:

  • If a length is provided alongside this pointer, the string is interpreted as a byte slice of that length (not NUL-terminated).
  • If no length is provided, the string is interpreted as NUL-terminated.