FREFunction

Type Alias FREFunction 

pub type FREFunction = unsafe extern "C" fn(*mut c_void, *mut c_void, u32, *const *mut c_void) -> *mut c_void;
Defines the signature for native calls that can be invoked via an instance of the AS3 ExtensionContext class.

The return value corresponds to the return value from the AS3 ExtensionContext.call method. Returning an invalid handle value is observed as null in AS3.