FREInitializer

Type Alias FREInitializer 

pub type FREInitializer = unsafe extern "C" fn(*mut *mut c_void, *mut unsafe extern "C" fn(*mut c_void, *const u8, *mut c_void, *mut u32, *mut *const FRENamedFunction), *mut Option<unsafe extern "C" fn(*mut c_void)>);
The initialization function provided by each extension must conform to the following signature.

Parameters

  • extDataToSet: Provided for the extension to store per-extension instance data. For example, if the extension creates globals per-instance, it can store a pointer to them here.
  • ctxInitializerToSet: Must be set to a function pointer of type FREContextInitializer. Will be invoked whenever the AS3 code creates a new context for this extension.
  • ctxFinalizerToSet: Must be set to a function pointer of type FREContextFinalizer, or left as None.