Module context

Module context 

Core implementation of the extension abstraction.

Structs

ContextRegistry
The extension-side concrete representation of a Context.
CooperativeContext
A handle to a context created by the current extension, which may become invalid under specific conditions.
CurrentContext
The current ANE context, on which most APIs in this crate depend.
ForeignContext
A handle to a context that may become invalid under specific conditions.

Traits

Context