mut_from

Function mut_from 

pub unsafe fn mut_from<'a>(raw: NonNullFREData) -> &'a mut dyn Any
In typical usage of this crate, this function should not be called directly.

Safety

The returned reference has an unbounded lifetime and is not tied to any input. Correct and safe usage requires the caller to impose additional lifetime constraints.