ref_from

Function ref_from 

pub unsafe fn ref_from<'a>(raw: NonNullFREData) -> &'a dyn Any
In typical usage of this crate, this function should not be called directly.

Safety

The returned reference has an unbounded lifetime and is not tied to any input. Correct and safe usage requires the caller to impose additional lifetime constraints.