Module function

Module function 

Structs

FunctionImplementation
Represents a native function implementation that can be registered as a method.
FunctionSet
A collection of functions associated with a specific context type.

Functions

trace
Sends a message to the debugger output.

Type Aliases

ContextFinalizer
The function is called before the Context Data is disposed, allowing final access and saving data to the Extension Data.
ContextInitializer
The function is used to initialize a Context.
Finalizer
The function receives ownership of the Extension Data, allowing it to be saved or disposed.
Function
The function can be associated with a Context and treated as its method.
Initializer
The function is used to initialize the extension.