pub struct FunctionDefinition { /* private fields */ }Expand description
In typical usage of this crate, instances of this type should not be constructed directly.
The crate::function! macro should be used to construct this type, as it provides a safer abstraction.
Implementations
Sourceimpl FunctionDefinition
impl FunctionDefinition
pub fn raw_name(&self) -> &UCStr
pub fn raw_func(&self) -> FREFunction
pub const fn new(raw_name: UCStr, raw_func: FREFunction) -> Self