FunctionSet

Struct FunctionSet 

pub struct FunctionSet { /* private fields */ }
A collection of functions associated with a specific context type.

This type is used to construct a set of functions for a Context. Once registered, these functions are referred to as methods within this crate, and can be invoked from AS3 via ExtensionContext.call.

Implementations

Source

impl FunctionSet

pub fn new() -> Self

pub fn with_capacity(capacity: usize) -> Self

pub fn add( &mut self, name: Option<UCStr>, func_data: Option<Box<dyn Any>>, func_impl: &'static FunctionImplementation, )

Adds a function that can be registered as a method.

Parameters
  • name: The method name. If None, the raw name of func_impl is used.
  • func_data: Data associated with this method. It will be dropped after ContextFinalizer returns.
  • func_impl: The method implementation created by the function! macro.
Panics

Panics if a function with the same name has already been added.

Callers must ensure that each name is unique within this set.