pub type ContextFinalizer = fn(ctx: &mut CurrentContext<'_>);Expand description
The function is called before the Context Data is disposed, allowing final access and saving data to the Extension Data.
pub type ContextFinalizer = fn(ctx: &mut CurrentContext<'_>);The function is called before the Context Data is disposed, allowing final access and saving data to the Extension Data.