Finalizer

Type Alias Finalizer 

pub type Finalizer = fn(ext_data: Option<Box<dyn Any>>);
The function receives ownership of the Extension Data, allowing it to be saved or disposed.

The runtime does NOT guarantee that this function will be called before process termination.