NativeWindow

Struct NativeWindow 

pub struct NativeWindow<'a>(/* private fields */);
A reference to the AS3 object flash.display.NativeWindow.

Some properties and methods are not yet implemented.

Implementations

Source

impl<'a> NativeWindow<'a>

pub fn get_stage(self) -> Stage<'a>

pub fn with<F, R>(self, f: F) -> R
where F: Sync + FnOnce(NonNullHandle) -> R,

Passes the underlying native handle to the provided closure.

The NonNullHandle is only valid for the duration of this closure call.

During the closure call stack, the Flash runtime is in a restricted state where most APIs are unavailable, and Sync is used to prevent illegal FFI call ordering.