pub struct Object<'a>(/* private fields */);Expand description
A reference to an AS3 object.
This type assumes that the underlying handle is always valid. The runtime is responsible for ensuring the correctness and lifetime of the handle.
The handle may still be as3::null, depending on the API behavior.
In such cases, as3::null is treated as a valid value at the ABI level,
but may represent the absence of an object.
Implementations
Sourceimpl<'a> Object<'a>
impl<'a> Object<'a>
pub fn new(ctx: &CurrentContext<'a>) -> NonNullObject<'a>
pub fn non_null(self) -> Option<NonNullObject<'a>>