pub unsafe extern "C" fn FREGetFREContextFromExtensionContext(
objExtensionContext: *mut c_void,
pContext: *mut *mut c_void,
) -> FREResultExpand description
Get the FREContext object associated with any ExtensionContext object. Note that
the FREContext object may become invalid based on what happens with the other ExtensionContext,
so this value should not be cached between function calls.
Parameters
objExtensionContext: TheExtensionContext(AS3 object) for which theFREContexthandle is required.pContext: TheFREContext(C handle) associated with the givenExtensionContext.