Core implementation of the extension abstraction.
Structs
- Context
Registry - The extension-side concrete representation of a
Context. - Cooperative
Context - A handle to a context created by the current extension, which may become invalid under specific conditions.
- Current
Context - The current ANE context, on which most APIs in this crate depend.
- Foreign
Context - A handle to a context that may become invalid under specific conditions.