ContextRegistry

Struct ContextRegistry 

pub struct ContextRegistry { /* private fields */ }
The extension-side concrete representation of a Context.

This can be considered the actual context instance, while Context serves as an abstract handle or outer wrapper around it.

This struct is only constructed via FlashRuntime::with_context_initializer.

Implementations

Source

impl ContextRegistry

pub fn context_type(&self) -> Option<UCStr>

pub fn context_data(&self) -> Option<&dyn Any>

pub fn context_data_mut(&mut self) -> &mut Option<Box<dyn Any>>

pub unsafe fn extension_data(&self) -> Option<&dyn Any>

Returns a reference to the extension data.

Safety

This method assumes that ext_data was either constructed via Data::into_raw or is a null pointer.

Violating these assumptions may lead to undefined behavior.

pub unsafe fn extension_data_mut(&mut self) -> Option<&mut dyn Any>

Returns a mutable reference to the extension data.

Safety

This method assumes that ext_data was either constructed via Data::into_raw or is a null pointer.

Violating these assumptions may lead to undefined behavior.