This module provides safe conversions between concrete typed instances and raw pointers for native data.
Box<dyn Any> is a fat pointer stored on the stack. Casting it directly
Traits
- Data
- Should be implemented for all native data types to ensure safe pointer passing and correct memory management. Native data includes Extension Data, Context Data, and Function data.