pub enum ExternalError<'a> {
C(FfiError),
ActionScript(Option<Object<'a>>),
}Variants
C(FfiError)
ActionScript(Option<Object<'a>>)
May be None if the thrown object is ignored or unavailable.
Implementations
Sourceimpl<'a> ExternalError<'a>
impl<'a> ExternalError<'a>
Sourcepub fn try_from(result: FREResult, thrown: Option<Object<'a>>) -> Option<Self>
pub fn try_from(result: FREResult, thrown: Option<Object<'a>>) -> Option<Self>
Attempts to convert a FREResult into ExternalError.
If the result represents an ActionScript error and thrown is Some,
the provided object is used as the error object.
If thrown is None, the thrown object is ignored or unavailable.
When an ActionScript throw occurs, the provided object is assumed to be a valid as3::Object.
However, ActionScript may throw as3::null.