pub enum ExternalError<'a> {
C(FfiError),
ActionScript(ActionScriptError<'a>),
}Variants
C(FfiError)
ActionScript(ActionScriptError<'a>)
Implementations
Sourceimpl<'a> ExternalError<'a>
impl<'a> ExternalError<'a>
Sourcepub fn try_from(
result: FREResult,
thrown: Option<Object<'a>>,
) -> Result<Self, ()>
pub fn try_from( result: FREResult, thrown: Option<Object<'a>>, ) -> Result<Self, ()>
Attempts to convert a FREResult into ExternalError.
If the result represents an ActionScript error and thrown is Some,
the provided object is used as the error value.
If thrown is None, the thrown object is ignored or assumed unavailable.
Notes
When an ActionScript throw occurs, the provided object is assumed to be a valid FREObject.
However, ActionScript may throw [null].