EventDispatcher

Struct EventDispatcher 

pub struct EventDispatcher(/* private fields */);
A handle for dispatching events that may become invalid under the same conditions as Context.

In asynchronous scenarios, its validity is difficult to predict. Therefore, all APIs on this type are safe to call, but their execution results cannot be guaranteed or reliably observed.

Implementations

Source

impl EventDispatcher

pub fn dispatch(&self, event: Event)

pub fn debug(&self, message: impl AsRef<str>)