pub struct EventDispatcher(/* private fields */);Expand description
A handle for dispatching events that may become invalid under the same
conditions as Context.
In asynchronous scenarios, its validity is difficult to predict. Therefore, all APIs on this type are safe to call, but their execution results cannot be guaranteed or reliably observed.
Implementations