Skip to main contentModule function
Source - FunctionImplementation
- In typical usage of this crate, instances of this type should not be constructed directly.
- FunctionSet
- A collection of functions associated with a specific context type.
- ContextFinalizer
- The function is called before the Context Data is disposed,
allowing final access and saving data to the Extension Data.
- ContextInitializer
- The function is used to initialize a
Context. - Finalizer
- The function receives ownership of the Extension Data,
allowing it to be saved or disposed.
- Function
- The function can be associated with a
Context and treated as its method. - Initializer
- The function is used to initialize the extension.