Module function

Module function 

Structs

FunctionDefinition
In typical usage of this crate, instances of this type should not be constructed directly.
FunctionSet
A collection of functions associated with a specific context type.

Type Aliases

ContextFinalizer
ContextInitializer
Finalizer
Function
Initializer