pub struct FunctionSet { /* private fields */ }Expand description
A collection of functions associated with a specific context type.
This type is used to construct and register a set of functions for a Context.
Once registered, these functions are referred to as methods within this crate,
and can be invoked from ActionScript via ExtensionContext.call.
Implementations
Sourceimpl FunctionSet
impl FunctionSet
pub fn new() -> Self
pub fn with_capacity(capacity: usize) -> Self
Sourcepub fn add(
&mut self,
name: Option<UCStr>,
func_data: Option<impl Data>,
func: &FunctionDefinition,
)
pub fn add( &mut self, name: Option<UCStr>, func_data: Option<impl Data>, func: &FunctionDefinition, )
Adds a named function entry to the internal registry.
Panics
Panics if a function with the same name has already been added.
Callers must ensure that each name is unique within this registry.