ContextFinalizer

Type Alias ContextFinalizer 

pub type ContextFinalizer = fn(ctx: &CurrentContext<'_>);
The function is called before the Context Data is disposed, allowing final access and saving data to the Extension Data.