macro_rules! ucstringify {
{$($tokens:tt)*} => { ... };
}Expand description
Interprets the input tokens as a string literal and yields a const UCStr.
Whitespace between tokens is normalized in the same way as stringify!.
Note that the expanded results of the input tokens may change in the future. You should be careful if you rely on the output.
Examples
use fre_rs::prelude::*;
const METHOD_NAME: UCStr = fre_rs::ucstringify! (addChild);
const ERROR_MESSAGE: UCStr = fre_rs::ucstringify! {Invalid argument type. };
assert_eq! (METHOD_NAME.as_str(), "addChild");
assert_eq! (ERROR_MESSAGE.as_str(), "Invalid argument type.");