pub struct NativeWindow<'a>(/* private fields */);Expand description
A reference to the AS3 object flash.display.NativeWindow.
Some properties and methods are not yet implemented.
Implementations
Sourceimpl<'a> NativeWindow<'a>
impl<'a> NativeWindow<'a>
pub fn get_stage(self) -> Stage<'a>
Sourcepub fn with<F, R>(self, f: F) -> R
pub fn with<F, R>(self, f: F) -> R
Passes the underlying native handle to the provided closure.
The NonNullHandle is only valid for the duration of this closure call.
During the closure call stack, the Flash runtime is in a restricted state
where most APIs are unavailable, and Sync is used to prevent illegal
FFI call ordering.